function [residual, g1, g2, g3] = model_det1_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(38, 1);
T43 = y(15)/y(14)-(steady_state(6))/(steady_state(5));
T45 = params(11)/2*T43^2;
T99 = y(10)*params(4)/y(48);
T134 = (params(13)-1)/params(13);
T141 = x(it_, 4)*y(22)^T134+(1-x(it_, 4))*y(23)^T134;
T184 = 1/(params(28)-1)*params(29)^params(28);
T252 = exp(params(15)*(y(20)/y(21)-params(16)));
T265 = y(1)^(1-params(5));
T266 = y(21)/T265;
T267 = y(12)^params(5);
T316 = params(11)/2*(-y(15))/(y(14)*y(14))*2*T43;
T328 = params(11)/2*2*T43*1/y(14);
T382 = getPowerDeriv(T141,params(13)/(params(13)-1),1);
lhs =y(38);
rhs =log(y(10))-params(2)*y(12)^(1+params(3))/(1+params(3))+log(y(11))+params(4)*y(51);
residual(1)= lhs-rhs;
lhs =y(10)+y(16)+y(19)+y(31)*y(14)+y(15)+y(14)*T45;
rhs =y(12)*y(29)+y(37)*params(12)+params(14)*(x(it_-1, 2)*y(8)*y(6)+x(it_-1, 3)*y(9)*y(5));
residual(2)= lhs-rhs;
lhs =y(11);
rhs =y(37)*(1-params(12));
residual(3)= lhs-rhs;
lhs =y(37);
rhs =y(7)*y(4)+y(5)*y(9)*(1-x(it_-1, 3))+(y(31)*(1-params(1))+y(30))*(y(2)+y(3))+(x(it_-1, 2)*y(8)*y(6)+x(it_-1, 3)*y(9)*y(5))*(1-params(14));
residual(4)= lhs-rhs;
lhs =y(29);
rhs =y(10)*params(2)*y(12)^params(3);
residual(5)= lhs-rhs;
lhs =1;
rhs =T99*y(32);
residual(6)= lhs-rhs;
residual(7) = min(y(32)-(1-x(it_, 3))*y(34),y(19));
lhs =y(31)+T45-y(15)*params(11)*T43/y(14);
rhs =T99*((1-params(1))*y(50)+y(49));
residual(8)= lhs-rhs;
lhs =1+params(11)*T43;
rhs =T99*((1-params(1))*y(50)+y(49));
residual(9)= lhs-rhs;
lhs =y(13);
rhs =y(14)+y(15);
residual(10)= lhs-rhs;
lhs =y(14);
rhs =(1-params(1))*y(1);
residual(11)= lhs-rhs;
lhs =y(21);
rhs =T141^(params(13)/(params(13)-1));
residual(12)= lhs-rhs;
lhs =y(22)*y(35)^params(13);
rhs =y(21)*x(it_, 4)^params(13);
residual(13)= lhs-rhs;
lhs =y(23)*y(36)^params(13);
rhs =y(21)*(1-x(it_, 4))^params(13);
residual(14)= lhs-rhs;
lhs =y(22);
rhs =params(8)*y(26)^(1-params(5))*y(24)^params(5);
residual(15)= lhs-rhs;
lhs =y(29)*y(24);
rhs =params(5)*y(17);
residual(16)= lhs-rhs;
lhs =y(30)*y(26);
rhs =(1-params(5))*y(17);
residual(17)= lhs-rhs;
lhs =y(42);
rhs =y(22)*y(35)/y(17);
residual(18)= lhs-rhs;
lhs =y(40);
rhs =T184*y(43)^(1-params(28));
residual(19)= lhs-rhs;
lhs =y(41);
rhs =1-y(40)+y(28)/y(17)*(y(43)-(1-y(40)));
residual(20)= lhs-rhs;
lhs =y(42)*y(41);
rhs =y(33);
residual(21)= lhs-rhs;
lhs =y(42)*y(40);
rhs =params(6);
residual(22)= lhs-rhs;
lhs =y(44);
rhs =y(42)*y(43);
residual(23)= lhs-rhs;
lhs =y(23);
rhs =params(9)*y(27)^(1-params(5))*y(25)^params(5);
residual(24)= lhs-rhs;
lhs =y(29)*y(25);
rhs =params(5)*y(18);
residual(25)= lhs-rhs;
lhs =y(30)*y(27);
rhs =(1-params(5))*y(18);
residual(26)= lhs-rhs;
lhs =y(47);
rhs =y(23)*y(36)/y(18);
residual(27)= lhs-rhs;
lhs =y(46);
rhs =1-y(45);
residual(28)= lhs-rhs;
lhs =y(47)*y(46);
rhs =y(33);
residual(29)= lhs-rhs;
lhs =y(47)*y(45);
rhs =params(7);
residual(30)= lhs-rhs;
lhs =y(16)*(y(33)-y(32));
rhs =y(28)*y(42)*(y(43)-(1-y(40)));
residual(31)= lhs-rhs;
lhs =y(28);
rhs =y(16)*x(it_, 1);
residual(32)= lhs-rhs;
lhs =y(33)*(1-x(it_, 2));
rhs =y(34)*T252;
residual(33)= lhs-rhs;
lhs =y(16)+y(20);
rhs =y(17)+y(18);
residual(34)= lhs-rhs;
lhs =y(12);
rhs =y(24)+y(25);
residual(35)= lhs-rhs;
lhs =y(1);
rhs =y(26)+y(27);
residual(36)= lhs-rhs;
lhs =y(34);
rhs =params(10);
residual(37)= lhs-rhs;
lhs =y(39);
rhs =T266/T267;
residual(38)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(38, 55);

  %
  % Jacobian matrix
  %

  g1(1,10)=(-(1/y(10)));
  g1(1,11)=(-(1/y(11)));
  g1(1,12)=params(2)*getPowerDeriv(y(12),1+params(3),1)/(1+params(3));
  g1(1,38)=1;
  g1(1,51)=(-params(4));
  g1(2,10)=1;
  g1(2,12)=(-y(29));
  g1(2,14)=y(31)+T45+y(14)*T316;
  g1(2,15)=1+y(14)*T328;
  g1(2,16)=1;
  g1(2,5)=(-(params(14)*x(it_-1, 3)*y(9)));
  g1(2,19)=1;
  g1(2,6)=(-(params(14)*x(it_-1, 2)*y(8)));
  g1(2,29)=(-y(12));
  g1(2,31)=y(14);
  g1(2,8)=(-(params(14)*x(it_-1, 2)*y(6)));
  g1(2,9)=(-(params(14)*x(it_-1, 3)*y(5)));
  g1(2,37)=(-params(12));
  g1(2,53)=(-(params(14)*y(8)*y(6)));
  g1(2,54)=(-(params(14)*y(9)*y(5)));
  g1(3,11)=1;
  g1(3,37)=(-(1-params(12)));
  g1(4,2)=(-(y(31)*(1-params(1))+y(30)));
  g1(4,3)=(-(y(31)*(1-params(1))+y(30)));
  g1(4,4)=(-y(7));
  g1(4,5)=(-(y(9)*(1-x(it_-1, 3))+x(it_-1, 3)*y(9)*(1-params(14))));
  g1(4,6)=(-(x(it_-1, 2)*y(8)*(1-params(14))));
  g1(4,30)=(-(y(2)+y(3)));
  g1(4,31)=(-((1-params(1))*(y(2)+y(3))));
  g1(4,7)=(-y(4));
  g1(4,8)=(-((1-params(14))*x(it_-1, 2)*y(6)));
  g1(4,9)=(-(y(5)*(1-x(it_-1, 3))+(1-params(14))*x(it_-1, 3)*y(5)));
  g1(4,37)=1;
  g1(4,53)=(-((1-params(14))*y(8)*y(6)));
  g1(4,54)=(-(y(5)*(-y(9))+(1-params(14))*y(9)*y(5)));
  g1(5,10)=(-(params(2)*y(12)^params(3)));
  g1(5,12)=(-(y(10)*params(2)*getPowerDeriv(y(12),params(3),1)));
  g1(5,29)=1;
  g1(6,10)=(-(y(32)*params(4)/y(48)));
  g1(6,48)=(-(y(32)*(-(y(10)*params(4)))/(y(48)*y(48))));
  g1(6,32)=(-T99);
  g1(7,19)=1-(y(19)>y(32)-(1-x(it_, 3))*y(34));
  g1(7,32)=y(19)>y(32)-(1-x(it_, 3))*y(34);
  g1(7,34)=(y(19)>y(32)-(1-x(it_, 3))*y(34))*(-(1-x(it_, 3)));
  g1(7,54)=y(34)*(y(19)>y(32)-(1-x(it_, 3))*y(34));
  g1(8,10)=(-(((1-params(1))*y(50)+y(49))*params(4)/y(48)));
  g1(8,48)=(-(((1-params(1))*y(50)+y(49))*(-(y(10)*params(4)))/(y(48)*y(48))));
  g1(8,14)=T316-(y(14)*y(15)*params(11)*(-y(15))/(y(14)*y(14))-y(15)*params(11)*T43)/(y(14)*y(14));
  g1(8,15)=T328-(params(11)*T43+y(15)*params(11)*1/y(14))/y(14);
  g1(8,49)=(-T99);
  g1(8,31)=1;
  g1(8,50)=(-((1-params(1))*T99));
  g1(9,10)=(-(((1-params(1))*y(50)+y(49))*params(4)/y(48)));
  g1(9,48)=(-(((1-params(1))*y(50)+y(49))*(-(y(10)*params(4)))/(y(48)*y(48))));
  g1(9,14)=params(11)*(-y(15))/(y(14)*y(14));
  g1(9,15)=params(11)*1/y(14);
  g1(9,49)=(-T99);
  g1(9,50)=(-((1-params(1))*T99));
  g1(10,13)=1;
  g1(10,14)=(-1);
  g1(10,15)=(-1);
  g1(11,1)=(-(1-params(1)));
  g1(11,14)=1;
  g1(12,21)=1;
  g1(12,22)=(-(x(it_, 4)*getPowerDeriv(y(22),T134,1)*T382));
  g1(12,23)=(-(T382*(1-x(it_, 4))*getPowerDeriv(y(23),T134,1)));
  g1(12,55)=(-(T382*(y(22)^T134-y(23)^T134)));
  g1(13,21)=(-(x(it_, 4)^params(13)));
  g1(13,22)=y(35)^params(13);
  g1(13,35)=y(22)*getPowerDeriv(y(35),params(13),1);
  g1(13,55)=(-(y(21)*getPowerDeriv(x(it_, 4),params(13),1)));
  g1(14,21)=(-((1-x(it_, 4))^params(13)));
  g1(14,23)=y(36)^params(13);
  g1(14,36)=y(23)*getPowerDeriv(y(36),params(13),1);
  g1(14,55)=(-(y(21)*(-(getPowerDeriv(1-x(it_, 4),params(13),1)))));
  g1(15,22)=1;
  g1(15,24)=(-(params(8)*y(26)^(1-params(5))*getPowerDeriv(y(24),params(5),1)));
  g1(15,26)=(-(y(24)^params(5)*params(8)*getPowerDeriv(y(26),1-params(5),1)));
  g1(16,17)=(-params(5));
  g1(16,24)=y(29);
  g1(16,29)=y(24);
  g1(17,17)=(-(1-params(5)));
  g1(17,26)=y(30);
  g1(17,30)=y(26);
  g1(18,17)=(-((-(y(22)*y(35)))/(y(17)*y(17))));
  g1(18,22)=(-(y(35)/y(17)));
  g1(18,35)=(-(y(22)/y(17)));
  g1(18,42)=1;
  g1(19,40)=1;
  g1(19,43)=(-(T184*getPowerDeriv(y(43),1-params(28),1)));
  g1(20,17)=(-((y(43)-(1-y(40)))*(-y(28))/(y(17)*y(17))));
  g1(20,28)=(-((y(43)-(1-y(40)))*1/y(17)));
  g1(20,40)=(-((-1)+y(28)/y(17)));
  g1(20,41)=1;
  g1(20,43)=(-(y(28)/y(17)));
  g1(21,33)=(-1);
  g1(21,41)=y(42);
  g1(21,42)=y(41);
  g1(22,40)=y(42);
  g1(22,42)=y(40);
  g1(23,42)=(-y(43));
  g1(23,43)=(-y(42));
  g1(23,44)=1;
  g1(24,23)=1;
  g1(24,25)=(-(params(9)*y(27)^(1-params(5))*getPowerDeriv(y(25),params(5),1)));
  g1(24,27)=(-(y(25)^params(5)*params(9)*getPowerDeriv(y(27),1-params(5),1)));
  g1(25,18)=(-params(5));
  g1(25,25)=y(29);
  g1(25,29)=y(25);
  g1(26,18)=(-(1-params(5)));
  g1(26,27)=y(30);
  g1(26,30)=y(27);
  g1(27,18)=(-((-(y(23)*y(36)))/(y(18)*y(18))));
  g1(27,23)=(-(y(36)/y(18)));
  g1(27,36)=(-(y(23)/y(18)));
  g1(27,47)=1;
  g1(28,45)=1;
  g1(28,46)=1;
  g1(29,33)=(-1);
  g1(29,46)=y(47);
  g1(29,47)=y(46);
  g1(30,45)=y(47);
  g1(30,47)=y(45);
  g1(31,16)=y(33)-y(32);
  g1(31,28)=(-(y(42)*(y(43)-(1-y(40)))));
  g1(31,32)=(-y(16));
  g1(31,33)=y(16);
  g1(31,40)=(-(y(42)*y(28)));
  g1(31,42)=(-(y(28)*(y(43)-(1-y(40)))));
  g1(31,43)=(-(y(42)*y(28)));
  g1(32,16)=(-x(it_, 1));
  g1(32,28)=1;
  g1(32,52)=(-y(16));
  g1(33,20)=(-(y(34)*T252*params(15)*1/y(21)));
  g1(33,21)=(-(y(34)*T252*params(15)*(-y(20))/(y(21)*y(21))));
  g1(33,33)=1-x(it_, 2);
  g1(33,34)=(-T252);
  g1(33,53)=(-y(33));
  g1(34,16)=1;
  g1(34,17)=(-1);
  g1(34,18)=(-1);
  g1(34,20)=1;
  g1(35,12)=1;
  g1(35,24)=(-1);
  g1(35,25)=(-1);
  g1(36,1)=1;
  g1(36,26)=(-1);
  g1(36,27)=(-1);
  g1(37,34)=1;
  g1(38,12)=(-((-(T266*getPowerDeriv(y(12),params(5),1)))/(T267*T267)));
  g1(38,1)=(-((-(y(21)*getPowerDeriv(y(1),1-params(5),1)))/(T265*T265)/T267));
  g1(38,21)=(-(1/T265/T267));
  g1(38,39)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],38,3025);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],38,166375);
end
end
