function [residual, g1, g2] = model_det1_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 38, 1);

%
% Model equations
%

T42 = y(6)/y(5)-(y(6))/(y(5));
T44 = params(11)/2*T42^2;
T93 = y(1)*params(4)/y(2);
T117 = (params(13)-1)/params(13);
T124 = x(4)*y(13)^T117+(1-x(4))*y(14)^T117;
T167 = 1/(params(28)-1)*params(29)^params(28);
T232 = exp(params(15)*(y(11)/y(12)-params(16)));
T245 = y(4)^(1-params(5));
T246 = y(12)/T245;
T247 = y(3)^params(5);
T296 = (-y(6))/(y(5)*y(5))-(-(y(6)))/((y(5))*(y(5)));
T299 = params(11)/2*T296*2*T42;
T312 = 1/y(5)-1/(y(5));
T314 = params(11)/2*2*T42*T312;
T368 = getPowerDeriv(T124,params(13)/(params(13)-1),1);
lhs =y(29);
rhs =log(y(1))-params(2)*y(3)^(1+params(3))/(1+params(3))+log(y(2))+y(29)*params(4);
residual(1)= lhs-rhs;
lhs =y(1)+y(7)+y(10)+y(22)*y(5)+y(6)+y(5)*T44;
rhs =y(3)*y(20)+y(28)*params(12)+params(14)*(x(2)*y(24)*y(11)+y(10)*x(3)*y(25));
residual(2)= lhs-rhs;
lhs =y(2);
rhs =y(28)*(1-params(12));
residual(3)= lhs-rhs;
lhs =y(28);
rhs =y(7)*y(23)+y(10)*y(25)*(1-x(3))+(y(22)*(1-params(1))+y(21))*(y(5)+y(6))+(x(2)*y(24)*y(11)+y(10)*x(3)*y(25))*(1-params(14));
residual(4)= lhs-rhs;
lhs =y(20);
rhs =y(1)*params(2)*y(3)^params(3);
residual(5)= lhs-rhs;
lhs =1;
rhs =y(23)*T93;
residual(6)= lhs-rhs;
residual(7) = min(y(23)-y(25)*(1-x(3)),y(10));
lhs =y(22)+T44-y(6)*params(11)*T42/y(5);
rhs =(y(22)*(1-params(1))+y(21))*T93;
residual(8)= lhs-rhs;
lhs =1+params(11)*T42;
rhs =(y(22)*(1-params(1))+y(21))*T93;
residual(9)= lhs-rhs;
lhs =y(4);
rhs =y(5)+y(6);
residual(10)= lhs-rhs;
lhs =y(5);
rhs =(1-params(1))*y(4);
residual(11)= lhs-rhs;
lhs =y(12);
rhs =T124^(params(13)/(params(13)-1));
residual(12)= lhs-rhs;
lhs =y(13)*y(26)^params(13);
rhs =y(12)*x(4)^params(13);
residual(13)= lhs-rhs;
lhs =y(14)*y(27)^params(13);
rhs =y(12)*(1-x(4))^params(13);
residual(14)= lhs-rhs;
lhs =y(13);
rhs =params(8)*y(17)^(1-params(5))*y(15)^params(5);
residual(15)= lhs-rhs;
lhs =y(20)*y(15);
rhs =params(5)*y(8);
residual(16)= lhs-rhs;
lhs =y(21)*y(17);
rhs =(1-params(5))*y(8);
residual(17)= lhs-rhs;
lhs =y(33);
rhs =y(13)*y(26)/y(8);
residual(18)= lhs-rhs;
lhs =y(31);
rhs =T167*y(34)^(1-params(28));
residual(19)= lhs-rhs;
lhs =y(32);
rhs =1-y(31)+y(19)/y(8)*(y(34)-(1-y(31)));
residual(20)= lhs-rhs;
lhs =y(33)*y(32);
rhs =y(24);
residual(21)= lhs-rhs;
lhs =y(33)*y(31);
rhs =params(6);
residual(22)= lhs-rhs;
lhs =y(35);
rhs =y(33)*y(34);
residual(23)= lhs-rhs;
lhs =y(14);
rhs =params(9)*y(18)^(1-params(5))*y(16)^params(5);
residual(24)= lhs-rhs;
lhs =y(20)*y(16);
rhs =params(5)*y(9);
residual(25)= lhs-rhs;
lhs =y(21)*y(18);
rhs =(1-params(5))*y(9);
residual(26)= lhs-rhs;
lhs =y(38);
rhs =y(14)*y(27)/y(9);
residual(27)= lhs-rhs;
lhs =y(37);
rhs =1-y(36);
residual(28)= lhs-rhs;
lhs =y(38)*y(37);
rhs =y(24);
residual(29)= lhs-rhs;
lhs =y(38)*y(36);
rhs =params(7);
residual(30)= lhs-rhs;
lhs =y(7)*(y(24)-y(23));
rhs =y(19)*y(33)*(y(34)-(1-y(31)));
residual(31)= lhs-rhs;
lhs =y(19);
rhs =y(7)*x(1);
residual(32)= lhs-rhs;
lhs =y(24)*(1-x(2));
rhs =y(25)*T232;
residual(33)= lhs-rhs;
lhs =y(7)+y(11);
rhs =y(8)+y(9);
residual(34)= lhs-rhs;
lhs =y(3);
rhs =y(15)+y(16);
residual(35)= lhs-rhs;
lhs =y(4);
rhs =y(17)+y(18);
residual(36)= lhs-rhs;
lhs =y(25);
rhs =params(10);
residual(37)= lhs-rhs;
lhs =y(30);
rhs =T246/T247;
residual(38)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(38, 38);

  %
  % Jacobian matrix
  %

  g1(1,1)=(-(1/y(1)));
  g1(1,2)=(-(1/y(2)));
  g1(1,3)=params(2)*getPowerDeriv(y(3),1+params(3),1)/(1+params(3));
  g1(1,29)=1-params(4);
  g1(2,1)=1;
  g1(2,3)=(-y(20));
  g1(2,5)=y(22)+T44+y(5)*T299;
  g1(2,6)=1+y(5)*T314;
  g1(2,7)=1;
  g1(2,10)=1-params(14)*x(3)*y(25);
  g1(2,11)=(-(params(14)*x(2)*y(24)));
  g1(2,20)=(-y(3));
  g1(2,22)=y(5);
  g1(2,24)=(-(params(14)*x(2)*y(11)));
  g1(2,25)=(-(params(14)*y(10)*x(3)));
  g1(2,28)=(-params(12));
  g1(3,2)=1;
  g1(3,28)=(-(1-params(12)));
  g1(4,5)=(-(y(22)*(1-params(1))+y(21)));
  g1(4,6)=(-(y(22)*(1-params(1))+y(21)));
  g1(4,7)=(-y(23));
  g1(4,10)=(-(y(25)*(1-x(3))+x(3)*y(25)*(1-params(14))));
  g1(4,11)=(-(x(2)*y(24)*(1-params(14))));
  g1(4,21)=(-(y(5)+y(6)));
  g1(4,22)=(-((1-params(1))*(y(5)+y(6))));
  g1(4,23)=(-y(7));
  g1(4,24)=(-((1-params(14))*x(2)*y(11)));
  g1(4,25)=(-(y(10)*(1-x(3))+(1-params(14))*y(10)*x(3)));
  g1(4,28)=1;
  g1(5,1)=(-(params(2)*y(3)^params(3)));
  g1(5,3)=(-(y(1)*params(2)*getPowerDeriv(y(3),params(3),1)));
  g1(5,20)=1;
  g1(6,1)=(-(y(23)*params(4)/y(2)));
  g1(6,2)=(-(y(23)*(-(y(1)*params(4)))/(y(2)*y(2))));
  g1(6,23)=(-T93);
  g1(7,10)=1-(y(10)>y(23)-y(25)*(1-x(3)));
  g1(7,23)=y(10)>y(23)-y(25)*(1-x(3));
  g1(7,25)=(y(10)>y(23)-y(25)*(1-x(3)))*(-(1-x(3)));
  g1(8,1)=(-((y(22)*(1-params(1))+y(21))*params(4)/y(2)));
  g1(8,2)=(-((y(22)*(1-params(1))+y(21))*(-(y(1)*params(4)))/(y(2)*y(2))));
  g1(8,5)=T299-(y(5)*y(6)*params(11)*T296-y(6)*params(11)*T42)/(y(5)*y(5));
  g1(8,6)=T314-(params(11)*T42+y(6)*params(11)*T312)/y(5);
  g1(8,21)=(-T93);
  g1(8,22)=1-(1-params(1))*T93;
  g1(9,1)=(-((y(22)*(1-params(1))+y(21))*params(4)/y(2)));
  g1(9,2)=(-((y(22)*(1-params(1))+y(21))*(-(y(1)*params(4)))/(y(2)*y(2))));
  g1(9,5)=params(11)*T296;
  g1(9,6)=params(11)*T312;
  g1(9,21)=(-T93);
  g1(9,22)=(-((1-params(1))*T93));
  g1(10,4)=1;
  g1(10,5)=(-1);
  g1(10,6)=(-1);
  g1(11,4)=(-(1-params(1)));
  g1(11,5)=1;
  g1(12,12)=1;
  g1(12,13)=(-(x(4)*getPowerDeriv(y(13),T117,1)*T368));
  g1(12,14)=(-(T368*(1-x(4))*getPowerDeriv(y(14),T117,1)));
  g1(13,12)=(-(x(4)^params(13)));
  g1(13,13)=y(26)^params(13);
  g1(13,26)=y(13)*getPowerDeriv(y(26),params(13),1);
  g1(14,12)=(-((1-x(4))^params(13)));
  g1(14,14)=y(27)^params(13);
  g1(14,27)=y(14)*getPowerDeriv(y(27),params(13),1);
  g1(15,13)=1;
  g1(15,15)=(-(params(8)*y(17)^(1-params(5))*getPowerDeriv(y(15),params(5),1)));
  g1(15,17)=(-(y(15)^params(5)*params(8)*getPowerDeriv(y(17),1-params(5),1)));
  g1(16,8)=(-params(5));
  g1(16,15)=y(20);
  g1(16,20)=y(15);
  g1(17,8)=(-(1-params(5)));
  g1(17,17)=y(21);
  g1(17,21)=y(17);
  g1(18,8)=(-((-(y(13)*y(26)))/(y(8)*y(8))));
  g1(18,13)=(-(y(26)/y(8)));
  g1(18,26)=(-(y(13)/y(8)));
  g1(18,33)=1;
  g1(19,31)=1;
  g1(19,34)=(-(T167*getPowerDeriv(y(34),1-params(28),1)));
  g1(20,8)=(-((y(34)-(1-y(31)))*(-y(19))/(y(8)*y(8))));
  g1(20,19)=(-((y(34)-(1-y(31)))*1/y(8)));
  g1(20,31)=(-((-1)+y(19)/y(8)));
  g1(20,32)=1;
  g1(20,34)=(-(y(19)/y(8)));
  g1(21,24)=(-1);
  g1(21,32)=y(33);
  g1(21,33)=y(32);
  g1(22,31)=y(33);
  g1(22,33)=y(31);
  g1(23,33)=(-y(34));
  g1(23,34)=(-y(33));
  g1(23,35)=1;
  g1(24,14)=1;
  g1(24,16)=(-(params(9)*y(18)^(1-params(5))*getPowerDeriv(y(16),params(5),1)));
  g1(24,18)=(-(y(16)^params(5)*params(9)*getPowerDeriv(y(18),1-params(5),1)));
  g1(25,9)=(-params(5));
  g1(25,16)=y(20);
  g1(25,20)=y(16);
  g1(26,9)=(-(1-params(5)));
  g1(26,18)=y(21);
  g1(26,21)=y(18);
  g1(27,9)=(-((-(y(14)*y(27)))/(y(9)*y(9))));
  g1(27,14)=(-(y(27)/y(9)));
  g1(27,27)=(-(y(14)/y(9)));
  g1(27,38)=1;
  g1(28,36)=1;
  g1(28,37)=1;
  g1(29,24)=(-1);
  g1(29,37)=y(38);
  g1(29,38)=y(37);
  g1(30,36)=y(38);
  g1(30,38)=y(36);
  g1(31,7)=y(24)-y(23);
  g1(31,19)=(-(y(33)*(y(34)-(1-y(31)))));
  g1(31,23)=(-y(7));
  g1(31,24)=y(7);
  g1(31,31)=(-(y(33)*y(19)));
  g1(31,33)=(-(y(19)*(y(34)-(1-y(31)))));
  g1(31,34)=(-(y(33)*y(19)));
  g1(32,7)=(-x(1));
  g1(32,19)=1;
  g1(33,11)=(-(y(25)*T232*params(15)*1/y(12)));
  g1(33,12)=(-(y(25)*T232*params(15)*(-y(11))/(y(12)*y(12))));
  g1(33,24)=1-x(2);
  g1(33,25)=(-T232);
  g1(34,7)=1;
  g1(34,8)=(-1);
  g1(34,9)=(-1);
  g1(34,11)=1;
  g1(35,3)=1;
  g1(35,15)=(-1);
  g1(35,16)=(-1);
  g1(36,4)=1;
  g1(36,17)=(-1);
  g1(36,18)=(-1);
  g1(37,25)=1;
  g1(38,3)=(-((-(T246*getPowerDeriv(y(3),params(5),1)))/(T247*T247)));
  g1(38,4)=(-((-(y(12)*getPowerDeriv(y(4),1-params(5),1)))/(T245*T245)/T247));
  g1(38,12)=(-(1/T245/T247));
  g1(38,30)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],38,1444);
end
end
