%% This file is used to display optimal liberalization policy following a decline in SOE share
dynare model_det1

clear
PHIchange = 1;
save res_tran1 PHIchange
ifopt = 0;
% set ifopt = 0 if you want to just use the saved optimal liberalization policy (res_tran1_PHIchange.mat); 
% set ifopt = 1 if you want to do the optimization yourself. 

%% solve for optimal liberalization policy
if ifopt == 1
%% calibration
GAMMA0 = 0.5;
TAUL0 =0.0587;
TAUD0 =0.1582;
GAMMA1 = GAMMA0;
TAUL1 =TAUL0;
TAUD1 =TAUD0;
ALPHA_GAMMA = 0;
ALPHA_TAUL  = 0;
ALPHA_TAUD  = 0;

%% optimal policy with liberalization of both capital outflows and financial repression
TAUL1      = TAUL0;
ALPHA_TAUL = 0;
ALPHA_GAMMA = 0.1;
ALPHA_TAUD  = 0.5;
[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, exp(x(1)), TAUL0, TAUL0, TAUD0, 1-exp(x(2)), ALPHA_GAMMA, ALPHA_TAUL, ALPHA_TAUD,PHIchange),[log(GAMMA0) log(1-0.1)],optimset('MaxFunEvals',8000,'TolFun',1e-8));
GAMMA1 = exp(x(1));
TAUD1 = 1-exp(x(2));
[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, exp(x(1)), TAUL0, TAUL0, TAUD0, 1-exp(x(2)), (atan(x(3))+pi/2)/pi, ALPHA_TAUL, (atan(x(4))+pi/2)/pi,PHIchange),[log(GAMMA1) log(1-TAUD1) tan(pi*0.1-pi/2) tan(pi*0.5-pi/2)],optimset('MaxFunEvals',8000,'TolFun',1e-8));
opt_tdg = [exp(x(1)) 1-exp(x(2)) (atan(x(3))+pi/2)/pi  (atan(x(4))+pi/2)/pi -FVAL flag]
load res_tran1
save res_tran1 PHIchange opt_tdg

%% optimal policy with liberalization of  both capital inflows and financial repression
TAUD1      = TAUD0;
ALPHA_TAUD = 0;
ALPHA_GAMMA = 0.1;
ALPHA_TAUL  = 0.5;
[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, exp(x(1)), TAUL0, 1-exp(x(2)), TAUD0, TAUD1, ALPHA_GAMMA, ALPHA_TAUL, ALPHA_TAUD,PHIchange),[log(GAMMA0) log(1-TAUL0)],optimset('MaxFunEvals',8000,'TolFun',1e-8));
GAMMA1 = exp(x(1));
TAUL1 = 1-exp(x(2));
[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, exp(x(1)), TAUL0, 1-exp(x(2)), TAUD0, TAUD1, (atan(x(3))+pi/2)/pi, (atan(x(4))+pi/2)/pi, ALPHA_TAUD,PHIchange),[log(GAMMA1) log(1-TAUL1) tan(pi*0.1-pi/2) tan(pi*0.5-pi/2)],optimset('MaxFunEvals',8000,'TolFun',1e-8));
opt_tlg = [exp(x(1)) 1-exp(x(2)) (atan(x(3))+pi/2)/pi  (atan(x(4))+pi/2)/pi -FVAL flag]
load res_tran1
save res_tran1 PHIchange opt_tdg opt_tlg

%% optimal policy with full liberalization
GAMMA1 = 0;
ALPHA_GAMMA = 0;
[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, GAMMA1, TAUL0, 1-exp(x(1)), TAUD0, 1-exp(x(2)), ALPHA_GAMMA, (atan(x(3))+pi/2)/pi, (atan(x(4))+pi/2)/pi,PHIchange),[log(1-0.03) log(1+0.01)  -30 tan(pi*0.6-pi/2)],optimset('MaxIter', 10000,'MaxFunEvals',80000,'TolFun',1e-8));
vGAMMA1 = 0;
vTAUL1 = 1-exp(x(1));
vTAUD1 = 1-exp(x(2));
vALPHA_GAMMA = 0;
vALPHA_TAUL = (atan(x(3))+pi/2)/pi;
vALPHA_TAUD = (atan(x(4))+pi/2)/pi;
welfare_diff = -FVAL;
opt_diff0=[vGAMMA1 vTAUL1 vTAUD1 vALPHA_GAMMA vALPHA_TAUL vALPHA_TAUD welfare_diff flag]
load res_tran1
save res_tran1 PHIchange opt_tdg opt_tlg  opt_diff0

[x,FVAL,flag] = fminsearch(@(x) -welfare_tran1(GAMMA0, exp(x(1)), TAUL0, 1-exp(x(2)), TAUD0, 1-exp(x(3)), (atan(x(4))+pi/2)/pi, (atan(x(5))+pi/2)/pi, (atan(x(6))+pi/2)/pi,PHIchange),[log(0.001) log(1-opt_diff0(2)) log(1-opt_diff0(3))  -30 tan(pi*opt_diff0(5)-pi/2) tan(pi*opt_diff0(6)-pi/2)],optimset('MaxIter', 10000,'MaxFunEvals',80000,'TolFun',1e-8));
vGAMMA1 = exp(x(1));
vTAUL1 = 1-exp(x(2));
vTAUD1 = 1-exp(x(3));
vALPHA_GAMMA = (atan(x(4))+pi/2)/pi;
vALPHA_TAUL = (atan(x(5))+pi/2)/pi;
vALPHA_TAUD = (atan(x(6))+pi/2)/pi;
welfare_diff = -FVAL;
opt_diff1=[vGAMMA1 vTAUL1 vTAUD1 vALPHA_GAMMA vALPHA_TAUL vALPHA_TAUD welfare_diff flag]
load res_tran1
save res_tran1 PHIchange opt_tdg opt_tlg  opt_diff0 opt_diff1

%% save optimal liberalization policy results
save res_tran1_PHIchange PHIchange opt_tdg  opt_tlg opt_diff1 opt_diff0
end

%% display results
dynare model_det2
welfare0 = oo_.endo_simul(29,2);%corrected welfare in case 0, where the directed lending constraint Bg<=Bs is binding.

load res_tran1_PHIchange
GAMMA0 = 0.5;
TAUL0 =0.0587;
TAUD0 =0.1582;

BETA = 0.96^10;
case1 = [ TAUD0 NaN TAUL0 NaN GAMMA0 NaN welfare0];
case2 = [TAUD0 NaN opt_tlg(2) 1-opt_tlg(4) opt_tlg(1) 1-opt_tlg(3) opt_tlg(5)];
case3 = [opt_tdg(2) 1-opt_tdg(4) TAUL0 NaN  opt_tdg(1) 1-opt_tdg(3) opt_tdg(5)];
case4 = [opt_diff1(3) 1-opt_diff1(6) opt_diff1(2) 1-opt_diff1(5) opt_diff1(1) 1-opt_diff1(4) opt_diff1(7)];
Res =  [case1;case2;case3;case4]';
Res(7,:) = exp((Res(7,:)-Res(7,1))*(1-BETA))-1;
Res


